@@ -1,19 +1,20 @@
 """
 Pyinvoke tasks.py file for automating releases and admin stuff.
 
-To cut a new pymatgen release, use `invoke update-changelog` followed by `invoke release`.
+To cut a new pymatgen release:
 
-Author: Shyue Ping Ong
+    invoke update-changelog
+    invoke release
 """
 
 from __future__ import annotations
 
-import datetime
 import json
 import os
 import re
 import subprocess
 import webbrowser
+from datetime import datetime, timezone
 from typing import TYPE_CHECKING
 
 import requests
@@ -38,7 +39,7 @@ def make_doc(ctx: Context) -> None:
         ctx.run("touch apidoc/index.rst", warn=True)
         ctx.run("rm pymatgen.*.rst", warn=True)
         # ctx.run("rm pymatgen.*.md", warn=True)
-        ctx.run("sphinx-apidoc --implicit-namespaces -M -d 7 -o apidoc -f ../pymatgen ../**/tests/*")
+        ctx.run("sphinx-apidoc --implicit-namespaces -M -d 7 -o apidoc -f ../src/pymatgen ../**/tests/*")
 
         # Note: we use HTML building for the API docs to preserve search functionality.
         ctx.run("sphinx-build -b html apidoc html")  # HTML building.
@@ -89,12 +90,21 @@ def publish(ctx: Context) -> None:
 
 @task
 def set_ver(ctx: Context, version: str):
-    with open("setup.py") as file:
-        contents = file.read()
-        contents = re.sub(r"version=([^,]+),", f"version={version!r},", contents)
+    """
+    Set version in pyproject.toml file.
 
-    with open("setup.py", mode="w") as file:
-        file.write(contents)
+    Args:
+        ctx (Context): The context.
+        version (str): An input version.
+    """
+    with open("pyproject.toml") as file:
+        lines = [re.sub(r"^version = \"([^,]+)\"", f'version = "{version}"', line.rstrip()) for line in file]
+
+    with open("pyproject.toml", "w") as file:
+        file.write("\n".join(lines) + "\n")
+
+    ctx.run("ruff check --fix src")
+    ctx.run("ruff format pyproject.toml")
 
 
 @task
@@ -103,14 +113,15 @@ def release_github(ctx: Context, version: str) -> None:
     Release to Github using Github API.
 
     Args:
+        ctx (Context): The context.
         version (str): The version.
     """
-    with open("docs/CHANGES.md") as file:
+    with open("docs/CHANGES.md", encoding="utf-8") as file:
         contents = file.read()
-    tokens = re.split(r"\-+", contents)
+    tokens = re.split(r"\n\#\#\s", contents)
     desc = tokens[1].strip()
     tokens = desc.split("\n")
-    desc = "\n".join(tokens[:-1]).strip()
+    desc = "\n".join(tokens[1:]).strip()
     payload = {
         "tag_name": f"v{version}",
         "target_commitish": "master",
@@ -123,35 +134,7 @@ def release_github(ctx: Context, version: str) -> None:
         "https://api.github.com/repos/materialsproject/pymatgen/releases",
         data=json.dumps(payload),
         headers={"Authorization": f"token {os.environ['GITHUB_RELEASES_TOKEN']}"},
-    )
-    print(response.text)
-
-
-def post_discourse(version: str) -> None:
-    """
-    Post release announcement to http://discuss.matsci.org/c/pymatgen.
-
-    Args:
-        version (str): The version.
-    """
-    with open("CHANGES.rst") as file:
-        contents = file.read()
-    tokens = re.split(r"\-+", contents)
-    desc = tokens[1].strip()
-    tokens = desc.split("\n")
-    desc = "\n".join(tokens[:-1]).strip()
-    raw = f"v{version}\n\n{desc}"
-    payload = {
-        "topic_id": 36,
-        "raw": raw,
-    }
-    response = requests.post(
-        "https://discuss.matsci.org/c/pymatgen/posts.json",
-        data=payload,
-        params={
-            "api_username": os.environ["DISCOURSE_API_USERNAME"],
-            "api_key": os.environ["DISCOURSE_API_KEY"],
-        },
+        timeout=60,
     )
     print(response.text)
 
@@ -167,17 +150,18 @@ def update_changelog(ctx: Context, version: str | None = None, dry_run: bool = F
         dry_run (bool, optional): If True, the function will only print the changes without
             updating the actual change log file. Defaults to False.
     """
-    version = version or f"{datetime.datetime.now():%Y.%-m.%-d}"
+    version = version or f"{datetime.now(tz=timezone.utc):%Y.%-m.%-d}"
     output = subprocess.check_output(["git", "log", "--pretty=format:%s", f"v{__version__}..HEAD"])
     lines = []
     ignored_commits = []
     for line in output.decode("utf-8").strip().split("\n"):
         re_match = re.match(r"Merge pull request \#(\d+) from (.*)", line)
         if re_match and "materialsproject/dependabot/pip" not in line:
-            pr_number = re_match.group(1)
-            contributor, pr_name = re_match.group(2).split("/", 1)
+            pr_number = re_match[1]
+            contributor, pr_name = re_match[2].split("/", 1)
             response = requests.get(
-                f"https://api.github.com/repos/materialsproject/pymatgen/pulls/{pr_number}", timeout=600
+                f"https://api.github.com/repos/materialsproject/pymatgen/pulls/{pr_number}",
+                timeout=60,
             )
             lines += [f"* PR #{pr_number} from @{contributor} {pr_name}"]
             json_resp = response.json()
@@ -189,7 +173,7 @@ def update_changelog(ctx: Context, version: str | None = None, dry_run: bool = F
                         break
                     lines += [f"    {ll}"]
         ignored_commits += [line]
-    with open("docs/CHANGES.md") as file:
+    with open("docs/CHANGES.md", encoding="utf-8") as file:
         contents = file.read()
     delim = "##"
     tokens = contents.split(delim)
@@ -197,7 +181,7 @@ def update_changelog(ctx: Context, version: str | None = None, dry_run: bool = F
     if dry_run:
         print(tokens[0] + "##".join(tokens[1:]))
     else:
-        with open("docs/CHANGES.md", mode="w") as file:
+        with open("docs/CHANGES.md", mode="w", encoding="utf-8") as file:
             file.write(tokens[0] + "##".join(tokens[1:]))
         ctx.run("open docs/CHANGES.md")
     print("The following commit messages were not included...")
@@ -214,7 +198,7 @@ def release(ctx: Context, version: str | None = None, nodoc: bool = False) -> No
         version (str, optional): The version to release.
         nodoc (bool, optional): Whether to skip documentation generation.
     """
-    version = version or f"{datetime.datetime.now():%Y.%-m.%-d}"
+    version = version or f"{datetime.now(tz=timezone.utc):%Y.%-m.%-d}"
     ctx.run("rm -r dist build pymatgen.egg-info", warn=True)
     set_ver(ctx, version)
     if not nodoc:
@@ -225,7 +209,7 @@ def release(ctx: Context, version: str | None = None, nodoc: bool = False) -> No
     release_github(ctx, version)
 
     ctx.run("rm -f dist/*.*", warn=True)
-    ctx.run("python setup.py sdist bdist_wheel", warn=True)
+    ctx.run("python -m build", warn=True)
     ctx.run("twine upload --skip-existing dist/*.whl", warn=True)
     ctx.run("twine upload --skip-existing dist/*.tar.gz", warn=True)
     # post_discourse(ctx, warn=True)
@@ -235,6 +219,9 @@ def release(ctx: Context, version: str | None = None, nodoc: bool = False) -> No
 def open_doc(ctx: Context) -> None:
     """
     Open local documentation in web browser.
+
+    Args:
+        ctx (invoke.Context): The context object.
     """
     pth = os.path.abspath("docs/_build/html/index.html")
     webbrowser.open(f"file://{pth}")
