@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import platform
 from unittest import TestCase
 
 import numpy as np
@@ -55,7 +56,7 @@ def perturb(mol, scale, seed):
     rng = np.random.default_rng(seed=seed)
 
     dV = rng.normal(scale=scale, size=(len(mol), 3))
-    for site, dv in zip(mol, dV):
+    for site, dv in zip(mol, dV, strict=True):
         site.coords += dv
 
 
@@ -148,16 +149,19 @@ def generate_Si2O_cluster():
 
 @pytest.mark.skipif(ob_align_missing, reason="OBAlign is missing, Skipping")
 class TestMoleculeMatcher:
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_fit(self):
         self.fit_with_mapper(IsomorphismMolAtomMapper())
         self.fit_with_mapper(InchiMolAtomMapper())
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_get_rmsd(self):
         mol_matcher = MoleculeMatcher()
         mol1 = Molecule.from_file(f"{TEST_DIR}/t3.xyz")
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
         assert f"{mol_matcher.get_rmsd(mol1, mol2):7.3}" == "0.00488"
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_group_molecules(self):
         mol_matcher = MoleculeMatcher(tolerance=0.001)
         with open(f"{TEST_DIR}/mol_list.txt") as file:
@@ -236,24 +240,28 @@ class TestMoleculeMatcher:
         mol2 = Molecule.from_file(f"{TEST_DIR}/t4.xyz")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_strange_inchi(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/k1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/k2.sdf")
         assert mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_thiane(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/thiane1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/thiane2.sdf")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_thiane_ethynyl(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/thiane_ethynyl1.sdf")
         mol2 = Molecule.from_file(f"{TEST_DIR}/thiane_ethynyl2.sdf")
         assert not mol_matcher.fit(mol1, mol2)
 
+    @pytest.mark.skipif(platform.system() == "Windows", reason="Tests for openbabel failing on Win")
     def test_cdi_23(self):
         mol_matcher = MoleculeMatcher(tolerance=0.05, mapper=InchiMolAtomMapper())
         mol1 = Molecule.from_file(f"{TEST_DIR}/cdi_23_1.xyz")
@@ -304,7 +312,10 @@ class TestKabschMatcher:
 
         mol_matcher = KabschMatcher(mol1)
 
-        with pytest.raises(ValueError, match="The order of the species aren't matching! Please try using "):
+        with pytest.raises(
+            ValueError,
+            match="The order of the species aren't matching! Please try using ",
+        ):
             mol_matcher.fit(mol2)
 
     def test_mismatched_atom_order(self):
@@ -559,7 +570,8 @@ class TestKabschMatcherSi(TestCase):
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using PermInvMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
@@ -687,7 +699,8 @@ class TestKabschMatcherSi2O(TestCase):
     def test_mismatched_atoms(self):
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si_cluster_rotated.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using PermInvMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
@@ -706,7 +719,8 @@ class TestKabschMatcherSi2O(TestCase):
         # to handle arbitrary atom's order
         mol2 = Molecule.from_file(f"{TEST_DIR}/Si2O_cluster_permuted.xyz")
         with pytest.raises(
-            ValueError, match="The order of the species aren't matching! Please try using PermInvMatcher"
+            ValueError,
+            match="The order of the species aren't matching! Please try using PermInvMatcher",
         ):
             self.mol_matcher.fit(mol2)
 
