@@ -3,6 +3,7 @@ from __future__ import annotations
 import collections
 import unittest
 import unittest.mock
+from itertools import combinations
 from numbers import Number
 from unittest import TestCase
 
@@ -137,7 +138,13 @@ class TestTransformedPDEntry(TestCase):
 
     def test_composition(self):
         comp = self.transformed_entry.composition
-        expected_comp = Composition({DummySpecies("Xf"): 14 / 30, DummySpecies("Xg"): 1.0, DummySpecies("Xh"): 2 / 30})
+        expected_comp = Composition(
+            {
+                DummySpecies("Xf"): 14 / 30,
+                DummySpecies("Xg"): 1.0,
+                DummySpecies("Xh"): 2 / 30,
+            }
+        )
         assert comp == expected_comp
 
     def test_elements(self):
@@ -163,7 +170,11 @@ class TestTransformedPDEntry(TestCase):
     def test_normalize(self):
         norm_entry = self.transformed_entry.normalize(mode="atom")
         expected_comp = Composition(
-            {DummySpecies("Xf"): 7 / 23, DummySpecies("Xg"): 15 / 23, DummySpecies("Xh"): 1 / 23}
+            {
+                DummySpecies("Xf"): 7 / 23,
+                DummySpecies("Xg"): 15 / 23,
+                DummySpecies("Xh"): 1 / 23,
+            }
         )
         assert norm_entry.composition == expected_comp
 
@@ -180,7 +191,10 @@ class TestPhaseDiagram(PymatgenTest):
             lambda e: (not e.composition.is_element) or e.elements[0] != Element("Li"),
             self.entries,
         )
-        with pytest.raises(ValueError, match=r"Missing terminal entries for elements \['Fe', 'Li', 'O'\]"):
+        with pytest.raises(
+            ValueError,
+            match=r"Missing terminal entries for elements \['Fe', 'Li', 'O'\]",
+        ):
             PhaseDiagram(entries)
 
     def test_repr(self):
@@ -305,7 +319,10 @@ class TestPhaseDiagram(PymatgenTest):
         ):
             # test raises ValueError on entry with element not in the phase diagram
             U_entry = PDEntry("U", 0)
-            with pytest.raises(ValueError, match="Unable to get decomposition for PDEntry : U1 with energy"):
+            with pytest.raises(
+                ValueError,
+                match="Unable to get decomposition for PDEntry : U1 with energy",
+            ):
                 method(U_entry)
 
             # test raises ValueError on entry with very negative energy
@@ -441,12 +458,20 @@ class TestPhaseDiagram(PymatgenTest):
                     assert len(self.pd.get_element_profile(el, entry.composition)) <= len(self.pd.facets)
 
         expected = [
-            {"evolution": 1.0, "chempot": -4.2582781416666666, "reaction": "Li2O + 0.5 O2 -> Li2O2"},
+            {
+                "evolution": 1.0,
+                "chempot": -4.2582781416666666,
+                "reaction": "Li2O + 0.5 O2 -> Li2O2",
+            },
             {"evolution": 0, "chempot": -5.08859066, "reaction": "Li2O -> Li2O"},
-            {"evolution": -1.0, "chempot": -10.48758201, "reaction": "Li2O -> 2 Li + 0.5 O2"},
+            {
+                "evolution": -1.0,
+                "chempot": -10.48758201,
+                "reaction": "Li2O -> 2 Li + 0.5 O2",
+            },
         ]
         result = self.pd.get_element_profile(Element("O"), Composition("Li2O"))
-        for d1, d2 in zip(expected, result):
+        for d1, d2 in zip(expected, result, strict=True):
             assert d1["evolution"] == approx(d2["evolution"])
             assert d1["chempot"] == approx(d2["chempot"])
             assert d1["reaction"] == str(d2["reaction"])
@@ -504,7 +529,7 @@ class TestPhaseDiagram(PymatgenTest):
             Composition("Li0.3243244Fe0.1621621O0.51351349"),
             Composition("Li3FeO4").fractional_composition,
         ]
-        for crit, exp in zip(comps, expected):
+        for crit, exp in zip(comps, expected, strict=True):
             assert crit.almost_equals(exp, rtol=0, atol=1e-5)
 
         comps = self.pd.get_critical_compositions(c1, c3)
@@ -514,7 +539,7 @@ class TestPhaseDiagram(PymatgenTest):
             Composition("Li5FeO4").fractional_composition,
             Composition("Li2O").fractional_composition,
         ]
-        for crit, exp in zip(comps, expected):
+        for crit, exp in zip(comps, expected, strict=True):
             assert crit.almost_equals(exp, rtol=0, atol=1e-5)
 
     def test_get_critical_compositions(self):
@@ -528,7 +553,7 @@ class TestPhaseDiagram(PymatgenTest):
             Composition("Li0.3243244Fe0.1621621O0.51351349") * 7.4,
             Composition("Li3FeO4"),
         ]
-        for crit, exp in zip(comps, expected):
+        for crit, exp in zip(comps, expected, strict=True):
             assert crit.almost_equals(exp, rtol=0, atol=1e-5)
 
         comps = self.pd.get_critical_compositions(c1, c3)
@@ -538,7 +563,7 @@ class TestPhaseDiagram(PymatgenTest):
             Composition("Li5FeO4") / 3,
             Composition("Li2O"),
         ]
-        for crit, exp in zip(comps, expected):
+        for crit, exp in zip(comps, expected, strict=True):
             assert crit.almost_equals(exp, rtol=0, atol=1e-5)
 
         # Don't fail silently if input compositions aren't in phase diagram
@@ -549,7 +574,10 @@ class TestPhaseDiagram(PymatgenTest):
         # For the moment, should also fail even if compositions are in the gppd
         # because it isn't handled properly
         gppd = GrandPotentialPhaseDiagram(self.pd.all_entries, {"Xe": 1}, [*self.pd.elements, Element("Xe")])
-        with pytest.raises(ValueError, match="Li3 Fe1 O4 Xe1 has elements not in the phase diagram O, Fe, Li"):
+        with pytest.raises(
+            ValueError,
+            match="Li3 Fe1 O4 Xe1 has elements not in the phase diagram O, Fe, Li",
+        ):
             gppd.get_critical_compositions(Composition("Fe2O3"), Composition("Li3FeO4Xe"))
 
         # check that the function still works though
@@ -559,7 +587,7 @@ class TestPhaseDiagram(PymatgenTest):
             Composition("Li0.3243244Fe0.1621621O0.51351349") * 7.4,
             Composition("Li3FeO4"),
         ]
-        for crit, exp in zip(comps, expected):
+        for crit, exp in zip(comps, expected, strict=True):
             assert crit.almost_equals(exp, rtol=0, atol=1e-5)
 
         # case where the endpoints are identical
@@ -700,6 +728,18 @@ class TestCompoundPhaseDiagram(TestCase):
     def test_str(self):
         assert str(self.pd) == "Xf-Xg phase diagram\n4 stable phases: \nLiFeO2, Li2O, Li5FeO4, Fe2O3"
 
+    def test_num2str(self):
+        ret = set()
+
+        num = 100
+        for idx in range(num):
+            val = CompoundPhaseDiagram.num2str(idx)
+            assert val.isalpha()
+            assert ord(val[0]) >= ord("f")
+            ret.add(val)
+
+        assert len(ret) == num
+
 
 class TestPatchedPhaseDiagram(TestCase):
     def setUp(self):
@@ -710,6 +750,7 @@ class TestPatchedPhaseDiagram(TestCase):
 
         self.pd = PhaseDiagram(entries=self.entries)
         self.ppd = PatchedPhaseDiagram(entries=self.entries)
+        self.ppd_all = PatchedPhaseDiagram(entries=self.entries, keep_all_spaces=True)
 
         # novel entries not in any of the patches
         self.novel_comps = [Composition("H5C2OP"), Composition("V2PH4C")]
@@ -757,7 +798,11 @@ class TestPatchedPhaseDiagram(TestCase):
 
         # test dims of sub PDs
         dim_counts = collections.Counter(pd.dim for pd in self.ppd.pds.values())
-        assert dim_counts == {3: 7, 2: 6, 4: 2}
+        assert dim_counts == {4: 2, 3: 2}
+
+        # test dims of sub PDs
+        dim_counts = collections.Counter(pd.dim for pd in self.ppd_all.pds.values())
+        assert dim_counts == {2: 8, 3: 7, 4: 2}
 
     def test_get_hull_energy(self):
         for comp in self.novel_comps:
@@ -773,7 +818,7 @@ class TestPatchedPhaseDiagram(TestCase):
             assert np.isclose(e_above_hull_pd, e_above_hull_ppd)
 
     def test_repr(self):
-        assert repr(self.ppd) == str(self.ppd) == "PatchedPhaseDiagram covering 15 sub-spaces"
+        assert repr(self.ppd) == str(self.ppd) == "PatchedPhaseDiagram covering 4 sub-spaces"
 
     def test_as_from_dict(self):
         ppd_dict = self.ppd.as_dict()
@@ -811,7 +856,8 @@ class TestPatchedPhaseDiagram(TestCase):
         pd = self.ppd[chem_space]
         assert isinstance(pd, PhaseDiagram)
         assert chem_space in pd._qhull_spaces
-        assert str(pd) == "V-C phase diagram\n4 stable phases: \nC, V, V6C5, V2C"
+        assert len(str(pd)) == 186
+        assert str(pd).startswith("V-H-C-O phase diagram\n25 stable phases:")
 
         with pytest.raises(KeyError, match="frozenset"):
             self.ppd[frozenset(map(Element, "HBCNOFPS"))]
@@ -831,6 +877,19 @@ class TestPatchedPhaseDiagram(TestCase):
         assert self.ppd[unlikely_chem_space] == self.pd
         del self.ppd[unlikely_chem_space]  # test __delitem__() and restore original state
 
+    def test_remove_redundant_spaces(self):
+        spaces = tuple(frozenset(entry.elements) for entry in self.ppd.qhull_entries)
+        # NOTE this is 5 not 4 as "He" is a non redundant space that gets dropped for other reasons
+        assert len(self.ppd.remove_redundant_spaces(spaces)) == 5
+
+        test = (
+            list(combinations(range(1, 7), 4))
+            + list(combinations(range(1, 10), 2))
+            + list(combinations([1, 4, 7, 9, 2], 5))
+        )
+        test = [frozenset(t) for t in test]
+        assert len(self.ppd.remove_redundant_spaces(test)) == 30
+
 
 class TestReactionDiagram(TestCase):
     def setUp(self):
@@ -921,7 +980,11 @@ class TestPDPlotter(TestCase):
 
     def test_matplotlib_plots(self):
         # Some very basic ("non")-tests. Just to make sure the methods are callable.
-        for plotter in (self.plotter_binary_mpl, self.plotter_ternary_mpl, self.plotter_quaternary_mpl):
+        for plotter in (
+            self.plotter_binary_mpl,
+            self.plotter_ternary_mpl,
+            self.plotter_quaternary_mpl,
+        ):
             ax = plotter.get_plot()
             assert isinstance(ax, plt.Axes)
 
