@@ -31,7 +31,10 @@ class TestTrajectory(PymatgenTest):
         self.molecules = []
         for coord in coords:
             mol = Molecule(
-                species, coord, charge=int(last_mol.charge), spin_multiplicity=int(last_mol.spin_multiplicity)
+                species,
+                coord,
+                charge=int(last_mol.charge),
+                spin_multiplicity=int(last_mol.spin_multiplicity),
             )
             self.molecules += [mol]
 
@@ -49,7 +52,7 @@ class TestTrajectory(PymatgenTest):
         if traj_1.species != traj_2.species:
             return False
 
-        return all(frame1 == frame2 for frame1, frame2 in zip(self.traj, traj_2))
+        return all(frame1 == frame2 for frame1, frame2 in zip(self.traj, traj_2, strict=False))
 
     def _get_lattice_species_and_coords(self):
         lattice = ((1, 0, 0), (0, 1, 0), (0, 0, 1))
@@ -78,63 +81,57 @@ class TestTrajectory(PymatgenTest):
         sliced_traj = self.traj[2:99:3]
         sliced_traj_from_structs = Trajectory.from_structures(self.structures[2:99:3])
 
-        if len(sliced_traj) == len(sliced_traj_from_structs):
-            assert all(sliced_traj[i] == sliced_traj_from_structs[i] for i in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(
+            sliced_traj_from_structs
+        ), f"{len(sliced_traj)=} != {len(sliced_traj_from_structs)=}"
+        assert all(sliced_traj[i] == sliced_traj_from_structs[i] for i in range(len(sliced_traj)))
 
         sliced_traj = self.traj[:-4:2]
         sliced_traj_from_structs = Trajectory.from_structures(self.structures[:-4:2])
 
-        if len(sliced_traj) == len(sliced_traj_from_structs):
-            assert all(sliced_traj[idx] == sliced_traj_from_structs[idx] for idx in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(
+            sliced_traj_from_structs
+        ), f"{len(sliced_traj)=} != {len(sliced_traj_from_structs)=}"
+        assert all(sliced_traj[idx] == sliced_traj_from_structs[idx] for idx in range(len(sliced_traj)))
 
         sliced_traj = self.traj_mols[:2]
         sliced_traj_from_mols = Trajectory.from_molecules(self.molecules[:2])
 
-        if len(sliced_traj) == len(sliced_traj_from_mols):
-            assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(sliced_traj_from_mols), f"{len(sliced_traj)=} != {len(sliced_traj_from_mols)=}"
+        assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
 
         sliced_traj = self.traj_mols[:-2]
         sliced_traj_from_mols = Trajectory.from_molecules(self.molecules[:-2])
 
-        if len(sliced_traj) == len(sliced_traj_from_mols):
-            assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(sliced_traj_from_mols), f"{len(sliced_traj)=} != {len(sliced_traj_from_mols)=}"
+        assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
 
     def test_list_slice(self):
         sliced_traj = self.traj[[10, 30, 70]]
         sliced_traj_from_structs = Trajectory.from_structures([self.structures[i] for i in [10, 30, 70]])
 
-        if len(sliced_traj) == len(sliced_traj_from_structs):
-            assert all(sliced_traj[i] == sliced_traj_from_structs[i] for i in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(
+            sliced_traj_from_structs
+        ), f"{len(sliced_traj)=} != {len(sliced_traj_from_structs)=}"
+        assert all(sliced_traj[i] == sliced_traj_from_structs[i] for i in range(len(sliced_traj)))
 
         sliced_traj = self.traj_mols[[1, 3]]
         sliced_traj_from_mols = Trajectory.from_molecules([self.molecules[i] for i in [1, 3]])
 
-        if len(sliced_traj) == len(sliced_traj_from_mols):
-            assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
-        else:
-            raise AssertionError
+        assert len(sliced_traj) == len(sliced_traj_from_mols), f"{len(sliced_traj)=} != {len(sliced_traj_from_mols)=}"
+        assert all(sliced_traj[i] == sliced_traj_from_mols[i] for i in range(len(sliced_traj)))
 
     def test_conversion(self):
         # Convert to displacements and back, and then check structures.
         self.traj.to_displacements()
         self.traj.to_positions()
 
-        assert all(struct == self.structures[i] for i, struct in enumerate(self.traj))
+        assert all(struct == self.structures[idx] for idx, struct in enumerate(self.traj))
 
         self.traj_mols.to_displacements()
         self.traj_mols.to_positions()
 
-        assert all(mol == self.molecules[i] for i, mol in enumerate(self.traj_mols))
+        assert all(mol == self.molecules[idx] for idx, mol in enumerate(self.traj_mols))
 
     def test_site_properties(self):
         lattice, species, coords = self._get_lattice_species_and_coords()
@@ -219,6 +216,10 @@ class TestTrajectory(PymatgenTest):
         expected = props[1:]
         assert traj[1:].frame_properties == expected
 
+        # test that the frame properties are set correctly when indexing an individual structure/molecule
+        expected = props[0]
+        assert traj[0].properties == expected
+
     def test_extend(self):
         traj = copy.deepcopy(self.traj)
 
@@ -392,7 +393,7 @@ class TestTrajectory(PymatgenTest):
         traj_1 = Trajectory(lattice=lattice, species=species, coords=coords, frame_properties=props_1)
 
         # energy and pressure properties
-        props_2 = [{"energy": e, "pressure": p} for e, p in zip(energy_2, pressure_2)]
+        props_2 = [{"energy": e, "pressure": p} for e, p in zip(energy_2, pressure_2, strict=True)]
         traj_2 = Trajectory(lattice=lattice, species=species, coords=coords, frame_properties=props_2)
 
         # no properties
@@ -423,8 +424,9 @@ class TestTrajectory(PymatgenTest):
         structures = [Structure.from_file(f"{VASP_IN_DIR}/POSCAR")]
         displacements = np.zeros((11, *np.shape(structures[-1].frac_coords)))
 
+        rng = np.random.default_rng()
         for idx in range(10):
-            displacement = np.random.random_sample(np.shape(structures[-1].frac_coords)) / 20
+            displacement = rng.random(np.shape(structures[-1].frac_coords)) / 20
             new_coords = displacement + structures[-1].frac_coords
             structures.append(Structure(structures[-1].lattice, structures[-1].species, new_coords))
             displacements[idx + 1, :, :] = displacement
@@ -439,8 +441,9 @@ class TestTrajectory(PymatgenTest):
 
         # Generate structures with different lattices
         structures = []
+        rng = np.random.default_rng()
         for _ in range(10):
-            new_lattice = np.dot(structure.lattice.matrix, np.diag(1 + np.random.random_sample(3) / 20))
+            new_lattice = np.dot(structure.lattice.matrix, np.diag(1 + rng.random(3) / 20))
             temp_struct = structure.copy()
             temp_struct.lattice = Lattice(new_lattice)
             structures.append(temp_struct)
@@ -448,7 +451,9 @@ class TestTrajectory(PymatgenTest):
         traj = Trajectory.from_structures(structures, constant_lattice=False)
 
         # Check if lattices were properly stored
-        assert all(np.allclose(struct.lattice.matrix, structures[i].lattice.matrix) for i, struct in enumerate(traj))
+        assert all(
+            np.allclose(struct.lattice.matrix, structures[idx].lattice.matrix) for idx, struct in enumerate(traj)
+        )
 
         # Check if the file is written correctly when lattice is not constant.
         traj.write_Xdatcar(filename=f"{self.tmp_path}/traj_test_XDATCAR")
@@ -484,13 +489,60 @@ class TestTrajectory(PymatgenTest):
             # Check composition of the first frame of the trajectory
             assert traj[0].formula == "Li2 Mn2 O4"
         except ImportError:
-            with pytest.raises(ImportError, match="ASE is required to read .traj files. pip install ase"):
+            with pytest.raises(
+                ImportError,
+                match="ASE is required to read .traj files. pip install ase",
+            ):
                 Trajectory.from_file(f"{TEST_DIR}/LiMnO2_chgnet_relax.traj")
 
     def test_index_error(self):
         with pytest.raises(IndexError, match="index=100 out of range, trajectory only has 100 frames"):
             self.traj[100]
         with pytest.raises(
-            TypeError, match=re.escape("bad index='test', expected one of [int, slice, list[int], numpy.ndarray]")
+            TypeError,
+            match=re.escape("bad index='test', expected one of [int, slice, list[int], numpy.ndarray]"),
         ):
             self.traj["test"]
+
+    def test_incorrect_dims(self):
+        # Good Inputs
+        const_lattice = ((1, 0, 0), (0, 1, 0), (0, 0, 1))
+        species = ["C", "O"]
+        coords = [
+            [[1.5, -0, 0], [1.9, -1.2, 0]],
+            [[1.5, -0, 0], [1.9, -1.2, 0]],
+            [[1.5, -0, 0], [1.9, -1.2, 0]],
+        ]
+
+        # Problematic Inputs
+        short_lattice = [
+            ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
+            ((1, 0, 0), (0, 1, 0), (0, 0, 1)),
+        ]
+        unphysical_lattice = [
+            ((1, 0, 0), (0, 1, 0)),
+            ((1, 0, 0), (0, 1, 0)),
+            ((1, 0, 0), (0, 1, 0)),
+        ]
+        extra_coords = [
+            [[1.5, -0, 0], [1.9, -1.2, 0], [1.9, -1.2, 0]],
+            [[1.5, -0, 0], [1.9, -1.2, 0], [1.9, -1.2, 0]],
+            [[1.5, -0, 0], [1.9, -1.2, 0], [1.9, -1.2, 0]],
+        ]
+        unphysical_coords = [
+            [[1.5, -0, 0, 1], [1.9, -1.2, 0, 1]],
+            [[1.5, -0, 0, 1], [1.9, -1.2, 0, 1]],
+            [[1.5, -0, 0, 1], [1.9, -1.2, 0, 1]],
+        ]
+        wrong_dim_coords = [[1.5, -0, 0, 1], [1.9, -1.2, 0, 1]]
+
+        with pytest.raises(ValueError, match=re.escape("lattice must have shape (M, 3, 3)!")):
+            Trajectory(species=species, coords=coords, lattice=short_lattice)
+        with pytest.raises(ValueError, match=re.escape("lattice must have shape (3, 3) or (M, 3, 3)")):
+            Trajectory(species=species, coords=coords, lattice=unphysical_lattice)
+        with pytest.raises(ValueError, match="must have the same number of sites!"):
+            Trajectory(species=species, coords=extra_coords, lattice=const_lattice)
+        with pytest.raises(ValueError, match=re.escape("coords must have shape (M, N, 3)")):
+            Trajectory(species=species, coords=unphysical_coords, lattice=const_lattice)
+        with pytest.raises(ValueError, match="coords must have 3 dimensions!"):
+            Trajectory(species=species, coords=wrong_dim_coords, lattice=const_lattice)
